==> kubernetes-model-autoscaling-5.12.4-sources.jar: io/fabric8/kubernetes/api/model/autoscaling/v2beta1/MetricStatusBuilder.java <==
package io.fabric8.kubernetes.api.model.autoscaling.v2beta1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;
public class MetricStatusBuilder extends io.fabric8.kubernetes.api.model.autoscaling.v2beta1.MetricStatusFluentImpl<io.fabric8.kubernetes.api.model.autoscaling.v2beta1.MetricStatusBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<io.fabric8.kubernetes.api.model.autoscaling.v2beta1.MetricStatus,io.fabric8.kubernetes.api.model.autoscaling.v2beta1.MetricStatusBuilder>{
  public MetricStatusBuilder() {
    this(false);
  }
  public MetricStatusBuilder(java.lang.Boolean validationEnabled) {
    this(new MetricStatus(), validationEnabled);
  }
  public MetricStatusBuilder(io.fabric8.kubernetes.api.model.autoscaling.v2beta1.MetricStatusFluent<?> fluent) {
    this(fluent, false);
  }
  public MetricStatusBuilder(io.fabric8.kubernetes.api.model.autoscaling.v2beta1.MetricStatusFluent<?> fluent,java.lang.Boolean validationEnabled) {
    this(fluent, new MetricStatus(), validationEnabled);
  }
  public MetricStatusBuilder(io.fabric8.kubernetes.api.model.autoscaling.v2beta1.MetricStatusFluent<?> fluent,io.fabric8.kubernetes.api.model.autoscaling.v2beta1.MetricStatus instance) {
    this(fluent, instance, false);
  }
  public MetricStatusBuilder(io.fabric8.kubernetes.api.model.autoscaling.v2beta1.MetricStatusFluent<?> fluent,io.fabric8.kubernetes.api.model.autoscaling.v2beta1.MetricStatus instance,java.lang.Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withContainerResource(instance.getContainerResource()); 
    fluent.withExternal(instance.getExternal()); 
    fluent.withObject(instance.getObject()); 
    fluent.withPods(instance.getPods()); 
    fluent.withResource(instance.getResource()); 
    fluent.withType(instance.getType()); 
    fluent.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  public MetricStatusBuilder(io.fabric8.kubernetes.api.model.autoscaling.v2beta1.MetricStatus instance) {
    this(instance,false);
  }
  public MetricStatusBuilder(io.fabric8.kubernetes.api.model.autoscaling.v2beta1.MetricStatus instance,java.lang.Boolean validationEnabled) {
    this.fluent = this; 
    this.withContainerResource(instance.getContainerResource()); 
    this.withExternal(instance.getExternal()); 
    this.withObject(instance.getObject()); 
    this.withPods(instance.getPods()); 
    this.withResource(instance.getResource()); 
    this.withType(instance.getType()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  io.fabric8.kubernetes.api.model.autoscaling.v2beta1.MetricStatusFluent<?> fluent;
  java.lang.Boolean validationEnabled;
  public io.fabric8.kubernetes.api.model.autoscaling.v2beta1.MetricStatus build() {
    MetricStatus buildable = new MetricStatus(fluent.getContainerResource(),fluent.getExternal(),fluent.getObject(),fluent.getPods(),fluent.getResource(),fluent.getType());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    MetricStatusBuilder that = (MetricStatusBuilder) o;
    if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

    if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
  }
  
}

==> kubernetes-model-autoscaling-6.4.0-sources.jar: io/fabric8/kubernetes/api/model/autoscaling/v2beta1/MetricStatusBuilder.java <==
package io.fabric8.kubernetes.api.model.autoscaling.v2beta1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class MetricStatusBuilder extends MetricStatusFluentImpl<MetricStatusBuilder> implements VisitableBuilder<MetricStatus,MetricStatusBuilder>{
  public MetricStatusBuilder() {
    this(false);
  }
  public MetricStatusBuilder(Boolean validationEnabled) {
    this(new MetricStatus(), validationEnabled);
  }
  public MetricStatusBuilder(MetricStatusFluent<?> fluent) {
    this(fluent, false);
  }
  public MetricStatusBuilder(MetricStatusFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new MetricStatus(), validationEnabled);
  }
  public MetricStatusBuilder(MetricStatusFluent<?> fluent,MetricStatus instance) {
    this(fluent, instance, false);
  }
  public MetricStatusBuilder(MetricStatusFluent<?> fluent,MetricStatus instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withContainerResource(instance.getContainerResource()); 
    fluent.withExternal(instance.getExternal()); 
    fluent.withObject(instance.getObject()); 
    fluent.withPods(instance.getPods()); 
    fluent.withResource(instance.getResource()); 
    fluent.withType(instance.getType()); 
    fluent.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  public MetricStatusBuilder(MetricStatus instance) {
    this(instance,false);
  }
  public MetricStatusBuilder(MetricStatus instance,Boolean validationEnabled) {
    this.fluent = this; 
    this.withContainerResource(instance.getContainerResource()); 
    this.withExternal(instance.getExternal()); 
    this.withObject(instance.getObject()); 
    this.withPods(instance.getPods()); 
    this.withResource(instance.getResource()); 
    this.withType(instance.getType()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  MetricStatusFluent<?> fluent;
  Boolean validationEnabled;
  public MetricStatus build() {
    MetricStatus buildable = new MetricStatus(fluent.getContainerResource(),fluent.getExternal(),fluent.getObject(),fluent.getPods(),fluent.getResource(),fluent.getType());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  
}
